#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NEGIF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NEGIF_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/negif.hpp>

#endif
